Class: MasterCard::API::Spendcontrols::Alertall

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/spendcontrols/alertall.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



122
123
124
125
126
127
128
129
130
# File 'lib/mastercard/api/spendcontrols/alertall.rb', line 122

def self.create(mapObj)
  #
  #Creates object of type Alertall
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Alertall] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("6da66199-ce40-4b76-a0da-c0d25d26d86a", Alertall.new(mapObj))
end

.deleteById(id, map = nil) ⇒ Object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/mastercard/api/spendcontrols/alertall.rb', line 65

def self.deleteById(id, map = nil)
  #Delete object of type Alertall by id

  #@param [String] id
  #@param [Dict] map, containing additional parameters
  #@return [Alertall] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status


  mapObj = Alertall.new
  if !(id.nil? || id.to_s.empty?)
    mapObj.set("id", id)
  end
  if !map.nil?
    if map.instance_of? RequestMap
      mapObj.setAll(map.getObject())
    else
      mapObj.setAll(map)
    end
  end

  return self.execute("53c55052-5808-4b77-ac52-454f154fbf81", mapObj)
end

.query(criteria) ⇒ Object



110
111
112
113
114
115
116
117
118
119
# File 'lib/mastercard/api/spendcontrols/alertall.rb', line 110

def self.query(criteria)
  #
  #Query objects of type Alertall by id and optional criteria
  #@param [Dict] criteria
  #@return [Alertall] object representing the response.
  #@raise [APIException] an exception from the response status
  #

  return self.execute("35fc8968-a349-4b2f-935c-77a7a3f7b4bd",Alertall.new(criteria))
end

Instance Method Details

#deleteObject



90
91
92
93
94
95
96
97
98
99
100
# File 'lib/mastercard/api/spendcontrols/alertall.rb', line 90

def delete
  #
  #Delete object of type Alertall

  #@param [String] id
  #@return [Alertall] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status
  #

  return self.class.execute("53c55052-5808-4b77-ac52-454f154fbf81", self)
end