Class: MasterCard::API::Spendcontrols::Alerts

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/spendcontrols/alerts.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



122
123
124
125
126
127
128
129
130
# File 'lib/mastercard/api/spendcontrols/alerts.rb', line 122

def self.create(mapObj)
  #
  #Creates object of type Alerts
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Alerts] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("209ab3d3-c9da-44f5-9d7a-c0eb22d53fb9", Alerts.new(mapObj))
end

.deleteById(id, map = nil) ⇒ Object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/mastercard/api/spendcontrols/alerts.rb', line 65

def self.deleteById(id, map = nil)
  #Delete object of type Alerts by id

  #@param [String] id
  #@param [Dict] map, containing additional parameters
  #@return [Alerts] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status


  mapObj = Alerts.new
  if !(id.nil? || id.to_s.empty?)
    mapObj.set("id", id)
  end
  if !map.nil?
    if map.instance_of? RequestMap
      mapObj.setAll(map.getObject())
    else
      mapObj.setAll(map)
    end
  end

  return self.execute("8307f215-af2d-4bbf-a12d-69e4e0b02067", mapObj)
end

.query(criteria) ⇒ Object



110
111
112
113
114
115
116
117
118
119
# File 'lib/mastercard/api/spendcontrols/alerts.rb', line 110

def self.query(criteria)
  #
  #Query objects of type Alerts by id and optional criteria
  #@param [Dict] criteria
  #@return [Alerts] object representing the response.
  #@raise [APIException] an exception from the response status
  #

  return self.execute("eb3d8f9f-085a-4002-98e7-0fda9f52f5ff",Alerts.new(criteria))
end

Instance Method Details

#deleteObject



90
91
92
93
94
95
96
97
98
99
100
# File 'lib/mastercard/api/spendcontrols/alerts.rb', line 90

def delete
  #
  #Delete object of type Alerts

  #@param [String] id
  #@return [Alerts] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status
  #

  return self.class.execute("8307f215-af2d-4bbf-a12d-69e4e0b02067", self)
end