Class: MasterCard::API::Spendcontrols::Amount

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/spendcontrols/amount.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



122
123
124
125
126
127
128
129
130
# File 'lib/mastercard/api/spendcontrols/amount.rb', line 122

def self.create(mapObj)
  #
  #Creates object of type Amount
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Amount] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("540b1cf7-e6b2-48c4-9ffa-353d9913d000", Amount.new(mapObj))
end

.deleteById(id, map = nil) ⇒ Object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/mastercard/api/spendcontrols/amount.rb', line 65

def self.deleteById(id, map = nil)
  #Delete object of type Amount by id

  #@param [String] id
  #@param [Dict] map, containing additional parameters
  #@return [Amount] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status


  mapObj = Amount.new
  if !(id.nil? || id.to_s.empty?)
    mapObj.set("id", id)
  end
  if !map.nil?
    if map.instance_of? RequestMap
      mapObj.setAll(map.getObject())
    else
      mapObj.setAll(map)
    end
  end

  return self.execute("27e3b26a-7818-4153-aff9-a3d5b66f591a", mapObj)
end

.query(criteria) ⇒ Object



110
111
112
113
114
115
116
117
118
119
# File 'lib/mastercard/api/spendcontrols/amount.rb', line 110

def self.query(criteria)
  #
  #Query objects of type Amount by id and optional criteria
  #@param [Dict] criteria
  #@return [Amount] object representing the response.
  #@raise [APIException] an exception from the response status
  #

  return self.execute("3eacb232-5fbc-4130-bd9f-f5ec70414980",Amount.new(criteria))
end

Instance Method Details

#deleteObject



90
91
92
93
94
95
96
97
98
99
100
# File 'lib/mastercard/api/spendcontrols/amount.rb', line 90

def delete
  #
  #Delete object of type Amount

  #@param [String] id
  #@return [Amount] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status
  #

  return self.class.execute("27e3b26a-7818-4153-aff9-a3d5b66f591a", self)
end