Class: MasterCard::API::Spendcontrols::Carddisable
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Spendcontrols::Carddisable
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/spendcontrols/carddisable.rb
Class Method Summary collapse
Instance Method Summary collapse
Class Method Details
.create(mapObj) ⇒ Object
122 123 124 125 126 127 128 129 130 |
# File 'lib/mastercard/api/spendcontrols/carddisable.rb', line 122 def self.create(mapObj) # #Creates object of type Carddisable # #@param Dict mapObj, containing the required parameters to create a new object #@return [Carddisable] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("155a9119-8b86-40ad-8e45-9eb5c8c2c2c2", Carddisable.new(mapObj)) end |
.deleteById(id, map = nil) ⇒ Object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mastercard/api/spendcontrols/carddisable.rb', line 65 def self.deleteById(id, map = nil) #Delete object of type Carddisable by id #@param [String] id #@param [Dict] map, containing additional parameters #@return [Carddisable] of the response of the deleted instance. #@raise [APIException] an exception from the response status mapObj = Carddisable.new if !(id.nil? || id.to_s.empty?) mapObj.set("id", id) end if !map.nil? if map.instance_of? RequestMap mapObj.setAll(map.getObject()) else mapObj.setAll(map) end end return self.execute("f439551d-f193-4089-8e80-272402709922", mapObj) end |
.query(criteria) ⇒ Object
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/mastercard/api/spendcontrols/carddisable.rb', line 110 def self.query(criteria) # #Query objects of type Carddisable by id and optional criteria #@param [Dict] criteria #@return [Carddisable] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("37021581-5fd6-4c78-bf8c-f03cb8a06794",Carddisable.new(criteria)) end |
Instance Method Details
#delete ⇒ Object
90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/mastercard/api/spendcontrols/carddisable.rb', line 90 def delete # #Delete object of type Carddisable #@param [String] id #@return [Carddisable] of the response of the deleted instance. #@raise [APIException] an exception from the response status # return self.class.execute("f439551d-f193-4089-8e80-272402709922", self) end |