Class: MasterCard::API::Spendcontrols::Channel

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/spendcontrols/channel.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



122
123
124
125
126
127
128
129
130
# File 'lib/mastercard/api/spendcontrols/channel.rb', line 122

def self.create(mapObj)
  #
  #Creates object of type Channel
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Channel] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("f8c8c3b4-034f-4e9a-9b8b-5725260e6014", Channel.new(mapObj))
end

.deleteById(id, map = nil) ⇒ Object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/mastercard/api/spendcontrols/channel.rb', line 65

def self.deleteById(id, map = nil)
  #Delete object of type Channel by id

  #@param [String] id
  #@param [Dict] map, containing additional parameters
  #@return [Channel] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status


  mapObj = Channel.new
  if !(id.nil? || id.to_s.empty?)
    mapObj.set("id", id)
  end
  if !map.nil?
    if map.instance_of? RequestMap
      mapObj.setAll(map.getObject())
    else
      mapObj.setAll(map)
    end
  end

  return self.execute("2128dfbd-be8f-4749-a260-cc486db575bc", mapObj)
end

.query(criteria) ⇒ Object



110
111
112
113
114
115
116
117
118
119
# File 'lib/mastercard/api/spendcontrols/channel.rb', line 110

def self.query(criteria)
  #
  #Query objects of type Channel by id and optional criteria
  #@param [Dict] criteria
  #@return [Channel] object representing the response.
  #@raise [APIException] an exception from the response status
  #

  return self.execute("775f9397-ae3a-4b84-bdfc-16eccb3b6d6a",Channel.new(criteria))
end

Instance Method Details

#deleteObject



90
91
92
93
94
95
96
97
98
99
100
# File 'lib/mastercard/api/spendcontrols/channel.rb', line 90

def delete
  #
  #Delete object of type Channel

  #@param [String] id
  #@return [Channel] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status
  #

  return self.class.execute("2128dfbd-be8f-4749-a260-cc486db575bc", self)
end