Class: MasterCard::API::Spendcontrols::Controls

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/spendcontrols/controls.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



122
123
124
125
126
127
128
129
130
# File 'lib/mastercard/api/spendcontrols/controls.rb', line 122

def self.create(mapObj)
  #
  #Creates object of type Controls
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Controls] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("b47956cd-c328-4e5a-a3e6-206252d1dc6e", Controls.new(mapObj))
end

.deleteById(id, map = nil) ⇒ Object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/mastercard/api/spendcontrols/controls.rb', line 65

def self.deleteById(id, map = nil)
  #Delete object of type Controls by id

  #@param [String] id
  #@param [Dict] map, containing additional parameters
  #@return [Controls] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status


  mapObj = Controls.new
  if !(id.nil? || id.to_s.empty?)
    mapObj.set("id", id)
  end
  if !map.nil?
    if map.instance_of? RequestMap
      mapObj.setAll(map.getObject())
    else
      mapObj.setAll(map)
    end
  end

  return self.execute("4d9aede9-6e73-40e3-a2f2-1002887a6cf3", mapObj)
end

.query(criteria) ⇒ Object



110
111
112
113
114
115
116
117
118
119
# File 'lib/mastercard/api/spendcontrols/controls.rb', line 110

def self.query(criteria)
  #
  #Query objects of type Controls by id and optional criteria
  #@param [Dict] criteria
  #@return [Controls] object representing the response.
  #@raise [APIException] an exception from the response status
  #

  return self.execute("2914ab7f-411a-4153-b422-bc75e7740b9d",Controls.new(criteria))
end

Instance Method Details

#deleteObject



90
91
92
93
94
95
96
97
98
99
100
# File 'lib/mastercard/api/spendcontrols/controls.rb', line 90

def delete
  #
  #Delete object of type Controls

  #@param [String] id
  #@return [Controls] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status
  #

  return self.class.execute("4d9aede9-6e73-40e3-a2f2-1002887a6cf3", self)
end