Class: MasterCard::API::Spendcontrols::Crossborder
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Spendcontrols::Crossborder
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/spendcontrols/crossborder.rb
Class Method Summary collapse
Instance Method Summary collapse
Class Method Details
.create(mapObj) ⇒ Object
122 123 124 125 126 127 128 129 130 |
# File 'lib/mastercard/api/spendcontrols/crossborder.rb', line 122 def self.create(mapObj) # #Creates object of type Crossborder # #@param Dict mapObj, containing the required parameters to create a new object #@return [Crossborder] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("a1288f20-6670-432b-9753-62c751ff3f49", Crossborder.new(mapObj)) end |
.deleteById(id, map = nil) ⇒ Object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mastercard/api/spendcontrols/crossborder.rb', line 65 def self.deleteById(id, map = nil) #Delete object of type Crossborder by id #@param [String] id #@param [Dict] map, containing additional parameters #@return [Crossborder] of the response of the deleted instance. #@raise [APIException] an exception from the response status mapObj = Crossborder.new if !(id.nil? || id.to_s.empty?) mapObj.set("id", id) end if !map.nil? if map.instance_of? RequestMap mapObj.setAll(map.getObject()) else mapObj.setAll(map) end end return self.execute("ccf87432-5234-46ab-805e-3ad66aacae7d", mapObj) end |
.query(criteria) ⇒ Object
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/mastercard/api/spendcontrols/crossborder.rb', line 110 def self.query(criteria) # #Query objects of type Crossborder by id and optional criteria #@param [Dict] criteria #@return [Crossborder] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("5dd3a077-01ee-4557-b497-9e1ae4532d73",Crossborder.new(criteria)) end |
Instance Method Details
#delete ⇒ Object
90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/mastercard/api/spendcontrols/crossborder.rb', line 90 def delete # #Delete object of type Crossborder #@param [String] id #@return [Crossborder] of the response of the deleted instance. #@raise [APIException] an exception from the response status # return self.class.execute("ccf87432-5234-46ab-805e-3ad66aacae7d", self) end |