Class: MasterCard::API::Spendcontrols::Declines

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/spendcontrols/declines.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



122
123
124
125
126
127
128
129
130
# File 'lib/mastercard/api/spendcontrols/declines.rb', line 122

def self.create(mapObj)
  #
  #Creates object of type Declines
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Declines] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("fdad2b2b-d646-4cd3-b032-14220f8cb29c", Declines.new(mapObj))
end

.deleteById(id, map = nil) ⇒ Object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/mastercard/api/spendcontrols/declines.rb', line 65

def self.deleteById(id, map = nil)
  #Delete object of type Declines by id

  #@param [String] id
  #@param [Dict] map, containing additional parameters
  #@return [Declines] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status


  mapObj = Declines.new
  if !(id.nil? || id.to_s.empty?)
    mapObj.set("id", id)
  end
  if !map.nil?
    if map.instance_of? RequestMap
      mapObj.setAll(map.getObject())
    else
      mapObj.setAll(map)
    end
  end

  return self.execute("c0d85a07-9a18-4e77-8626-ddb3cf69073d", mapObj)
end

.query(criteria) ⇒ Object



110
111
112
113
114
115
116
117
118
119
# File 'lib/mastercard/api/spendcontrols/declines.rb', line 110

def self.query(criteria)
  #
  #Query objects of type Declines by id and optional criteria
  #@param [Dict] criteria
  #@return [Declines] object representing the response.
  #@raise [APIException] an exception from the response status
  #

  return self.execute("85f1237d-1d2e-4ec5-a4f9-264e769c581a",Declines.new(criteria))
end

Instance Method Details

#deleteObject



90
91
92
93
94
95
96
97
98
99
100
# File 'lib/mastercard/api/spendcontrols/declines.rb', line 90

def delete
  #
  #Delete object of type Declines

  #@param [String] id
  #@return [Declines] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status
  #

  return self.class.execute("c0d85a07-9a18-4e77-8626-ddb3cf69073d", self)
end