Class: MasterCard::API::Spendcontrols::Geolocationalert

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/spendcontrols/geolocationalert.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



122
123
124
125
126
127
128
129
130
# File 'lib/mastercard/api/spendcontrols/geolocationalert.rb', line 122

def self.create(mapObj)
  #
  #Creates object of type Geolocationalert
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Geolocationalert] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("a8d9b869-616e-4a56-854e-6c542290aa26", Geolocationalert.new(mapObj))
end

.deleteById(id, map = nil) ⇒ Object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/mastercard/api/spendcontrols/geolocationalert.rb', line 65

def self.deleteById(id, map = nil)
  #Delete object of type Geolocationalert by id

  #@param [String] id
  #@param [Dict] map, containing additional parameters
  #@return [Geolocationalert] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status


  mapObj = Geolocationalert.new
  if !(id.nil? || id.to_s.empty?)
    mapObj.set("id", id)
  end
  if !map.nil?
    if map.instance_of? RequestMap
      mapObj.setAll(map.getObject())
    else
      mapObj.setAll(map)
    end
  end

  return self.execute("f29dd6e8-e908-40a1-ae1c-380e63a9ff69", mapObj)
end

.query(criteria) ⇒ Object



110
111
112
113
114
115
116
117
118
119
# File 'lib/mastercard/api/spendcontrols/geolocationalert.rb', line 110

def self.query(criteria)
  #
  #Query objects of type Geolocationalert by id and optional criteria
  #@param [Dict] criteria
  #@return [Geolocationalert] object representing the response.
  #@raise [APIException] an exception from the response status
  #

  return self.execute("2b70c5a2-700f-4eb3-9d17-6637a917c34a",Geolocationalert.new(criteria))
end

Instance Method Details

#deleteObject



90
91
92
93
94
95
96
97
98
99
100
# File 'lib/mastercard/api/spendcontrols/geolocationalert.rb', line 90

def delete
  #
  #Delete object of type Geolocationalert

  #@param [String] id
  #@return [Geolocationalert] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status
  #

  return self.class.execute("f29dd6e8-e908-40a1-ae1c-380e63a9ff69", self)
end