Class: MasterCard::API::Spendcontrols::Card
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Spendcontrols::Card
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/spendcontrols/card.rb
Class Method Summary collapse
Instance Method Summary collapse
Class Method Details
.create(mapObj) ⇒ Object
62 63 64 65 66 67 68 69 70 |
# File 'lib/mastercard/api/spendcontrols/card.rb', line 62 def self.create(mapObj) # #Creates object of type Card # #@param Dict mapObj, containing the required parameters to create a new object #@return [Card] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("4fdbff2b-135f-4919-a6b7-e558590f851a", Card.new(mapObj)) end |
.deleteById(id, map = nil) ⇒ Object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/mastercard/api/spendcontrols/card.rb', line 81 def self.deleteById(id, map = nil) #Delete object of type Card by id #@param [String] id #@param [Dict] map, containing additional parameters #@return [Card] of the response of the deleted instance. #@raise [APIException] an exception from the response status mapObj = Card.new if !(id.nil? || id.to_s.empty?) mapObj.set("id", id) end if !map.nil? if map.instance_of? RequestMap mapObj.setAll(map.getObject()) else mapObj.setAll(map) end end return self.execute("8e395139-d6da-4b46-9330-45c141c6ef35", mapObj) end |
.update(mapObj) ⇒ Object
121 122 123 124 125 126 127 128 129 |
# File 'lib/mastercard/api/spendcontrols/card.rb', line 121 def self.update(mapObj) # #Creates object of type Card # #@param Dict mapObj, containing the required parameters to create a new object #@return [Card] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("a0d1e30d-9fb1-4060-90d1-9d935cf57c84", Card.new(mapObj)) end |
Instance Method Details
#delete ⇒ Object
106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/mastercard/api/spendcontrols/card.rb', line 106 def delete # #Delete object of type Card #@param [String] id #@return [Card] of the response of the deleted instance. #@raise [APIException] an exception from the response status # return self.class.execute("8e395139-d6da-4b46-9330-45c141c6ef35", self) end |