Class: MasterCard::API::Spendcontrols::Declines

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/spendcontrols/declines.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



122
123
124
125
126
127
128
129
130
# File 'lib/mastercard/api/spendcontrols/declines.rb', line 122

def self.create(mapObj)
  #
  #Creates object of type Declines
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Declines] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("68222ec0-7d03-448f-989d-c84aed58bb74", Declines.new(mapObj))
end

.deleteById(id, map = nil) ⇒ Object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/mastercard/api/spendcontrols/declines.rb', line 65

def self.deleteById(id, map = nil)
  #Delete object of type Declines by id

  #@param [String] id
  #@param [Dict] map, containing additional parameters
  #@return [Declines] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status


  mapObj = Declines.new
  if !(id.nil? || id.to_s.empty?)
    mapObj.set("id", id)
  end
  if !map.nil?
    if map.instance_of? RequestMap
      mapObj.setAll(map.getObject())
    else
      mapObj.setAll(map)
    end
  end

  return self.execute("b6e3dd49-7521-4e57-b7a3-91777a244cd4", mapObj)
end

.query(criteria) ⇒ Object



110
111
112
113
114
115
116
117
118
119
# File 'lib/mastercard/api/spendcontrols/declines.rb', line 110

def self.query(criteria)
  #
  #Query objects of type Declines by id and optional criteria
  #@param [Dict] criteria
  #@return [Declines] object representing the response.
  #@raise [APIException] an exception from the response status
  #

  return self.execute("b59071f6-e39f-4af4-8ac8-b9c55cbe2ffc",Declines.new(criteria))
end

Instance Method Details

#deleteObject



90
91
92
93
94
95
96
97
98
99
100
# File 'lib/mastercard/api/spendcontrols/declines.rb', line 90

def delete
  #
  #Delete object of type Declines

  #@param [String] id
  #@return [Declines] of the response of the deleted instance.
  #@raise [APIException] an exception from the response status
  #

  return self.class.execute("b6e3dd49-7521-4e57-b7a3-91777a244cd4", self)
end